==> ulyxex.0.1.1.with-tinyMce.zip: pages/code/admin.php <==
<?php
class Admin extends Ulyxex  {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function version(){
		$dbLink = @mysql_connect(HOSTMYSQL,USERMYSQL,PASSMYSQL);
		$selectBase = @mysql_select_db(BASEMYSQL,$dbLink); 
		$version = mysql_get_server_info();
		@mysql_close($dbLink);
		return $version;
	}
	public function login($login,$password) {
		$query = "SELECT PASSWORD,USERLEVEL FROM ".USERS." WHERE LOGIN = '".$this->h->safe($login)."'";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat['PASSWORD'] == $password) {
			return $dat['USERLEVEL'];
		} else {
			exit($this->tr->w("bad login & password"));
		}
	}
	public function user_id($login) {
		$query = "SELECT ID FROM ".USERS." WHERE LOGIN = '".$login."'";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		
		return $dat['ID'];
	}
	public function user_params($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
}
class NextPages {
	function __construct($items,$action) {
		$this->h = new Html();
		$this->items = $items;
		$this->action = $action;
		$this->pos = isset($_GET['pg'])?$_GET['pg']:0;
	}
	public function numbers() {
		/* total pages */
		$pages = $this->items/ADMINITEMSBYPAGE; 
		$pages++;
		$result = "";
		if ($pages > 2) {
			for($i=1;$i < $pages;$i++) {
				$num = $i?strval($i):"0";
				if ($i == $this->pos) {
					$result .= "(".$this->h->ahref("admin.php?".$this->action."&amp;pg=".$num,$num).") ";
				} else {
					$result .= $this->h->ahref("admin.php?".$this->action."&amp;pg=".$num,$num)." ";
				}
			}
		}
		return $result;
	}
}
?>

==> ulyxex.0.1.2.with-tinyMce.zip: pages/code/admin.php <==
<?php
class Admin extends Ulyxex  {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function version(){
		$dbLink = @mysql_connect(HOSTMYSQL,USERMYSQL,PASSMYSQL);
		$selectBase = @mysql_select_db(BASEMYSQL,$dbLink); 
		$version = mysql_get_server_info();
		@mysql_close($dbLink);
		return $version;
	}
	public function login($login,$password) {
		$query = "SELECT PASSWORD,USERLEVEL FROM ".USERS." WHERE LOGIN = '".$this->h->safe($login)."'";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat['PASSWORD'] == $password) {
			return $dat['USERLEVEL'];
		} else {
			exit($this->tr->w("bad login or password !"));
		}
	}
	public function user_id($login) {
		$query = "SELECT ID FROM ".USERS." WHERE LOGIN = '".$login."'";
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		
		return $dat['ID'];
	}
	public function user_params($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function reset_form($action=Null) {
		$result = $this->h->p($this->h->input("submit","",$this->tr->w("no filters")).$this->h->input("hidden","reset",1));
		$result = $this->h->form($result,"reset","post","admin.php?action=".$action);
		return $result;
	}
	public function go_id($var=Null,$action=Null) {
		$result = $this->h->p($this->h->input("text",$var,"","size=4")." ".$this->h->input("submit","",$this->tr->w("go id")));
		$result = $this->h->form($result,"go_id","post","admin.php?action=".$action);
		return $result;
	}
	public function search_form($var=Null,$text=Null,$action=Null) {
		$result = $this->h->p($this->h->input("text",$var,"")." ".$this->h->input("submit","",$this->tr->w($text))); 
		$result = $this->h->form($result,"search","post","admin.php?action=".$action);
		return $result;
	}
}
class NextPages {
	function __construct($items,$action) {
		$this->h = new Html();
		$this->items = $items;
		$this->action = $action;
		$this->pos = isset($_GET['pg'])?$_GET['pg']:0;
	}
	public function numbers() {
		/* total pages */
		$pages = $this->items/ADMINITEMSBYPAGE; 
		$pages++;
		$result = "";
		if ($pages > 2) {
			for($i=1;$i < $pages;$i++) {
				$num = $i?strval($i):"0";
				if ($i == $this->pos) {
					$result .= "(".$this->h->ahref("admin.php?".$this->action."&amp;pg=".$num,$num).") ";
				} else {
					$result .= $this->h->ahref("admin.php?".$this->action."&amp;pg=".$num,$num)." ";
				}
			}
		}
		return $result;
	}
}
?>
